import { http } from '@/utils/http';
const mqtturl='https://szcx.zyyt.sinopec.com/mqttprod';//发布发布！！！！！，张祥瑞
// const mqtturl = 'http://10.75.15.246:8899/mqttprod';//测试使用，张祥瑞

export function gethomelist(config : object) { // 获取房间信息
	return http({
		url: '/RoomOperation/RoomOperation/gethomelist',
		method: 'GET',
		data: config
	})
}

export function testcontiont(config : object) { // 获取房间信息
	return http({
		url: mqtturl + '/mqttSubclient/mqttSubclient/testgetcontint',
		method: 'GET',
		data: config
	})
}

export function contiontmqtt(config : object) { // 链接mqtt
	return http({
		url: mqtturl + '/mqtt/mqtttest/getMqttPushClient',
		method: 'GET',
		data: config
	})
}


export function treeRootList(config : object) { // 查询部门树节点
	return http({
		url: '/sysdepartwlwcode/sysDepartWlwCode/rootList',
		method: 'GET',
		data: config
	})
}


export function selectfjkzbmforfjid(config : object) { // 查询部门树节点
	return http({
		url: '/RoomOperation/RoomOperation/selectfjkzbmforfjid',
		method: 'GET',
		data: config
	})
}

export function createdSwitch(config : object) { // 查询开关状态
	return http({
		url: mqtturl +
			"/mqttSubclientCreateSwitch/mqttSubclientCreateSwitch/createdSwitch",
		method: 'GET',
		data: config
	})
}

export function getMqttPushClient(config : object) { // 查询开关状态
	return http({
		url: mqtturl + '/mqtt/mqtttest/getMqttPushClient',
		method: 'GET',
		data: config
	})
}

export function treeChildList(config : object) { // 查询开关状态
	return http({
		url: '/sysdepartwlwcode/sysDepartWlwCode/childList',
		method: 'GET',
		data: config
	})
}


export function listAllRegions(config : object) { // 查询开关状态
	return http({
		url: '/sysdepartwlwcode/sysDepartWlwCode/getWlwTree',
		method: 'GET',
		data: config
	})
}

export function Selecthomelist(config : object) { // 查询开关状态
	return http({
		url: '/RoomOperation/RoomOperation/Selecthomelist',
		method: 'GET',
		data: config
	})
}

export function getsblb(config : object) { // 查询开关状态
	return http({
		url: '/RoomOperation/RoomOperation/getsblb',
		method: 'GET',
		data: config
	})
}

export function subscribeByOneTopic(config : object) { // 查询开关状态
	return http({
		url: mqtturl +'/mqttSubclient/mqttSubclient/subscribeByOneTopic',
		method: 'GET',
		data: config
	})
}

export function pushMqttsubscribeForYKQ(config : object) { // 查询开关状态
	return http({
		url: mqtturl +'/mqttpush/mqtttestpush/pushMqttsubscribeForYKQ',
		method: 'GET',
		data: config
	})
}
export function pushMqttsubscribeforSendInfo(config : object) { // 查询开关状态
	return http({
		url: mqtturl +'/mqttpush/mqtttestpush/pushMqttsubscribeforSendInfo',
		method: 'GET',
		data: config
	})
}
export function pushMqttsubscribe(config : object) { // 查询开关状态
	return http({
		url: mqtturl +'/mqttpush/mqtttestpush/pushMqttsubscribe',
		method: 'GET',
		data: config
	})
}
//--------------------------------------个人查询页面  end-----------------------------------------------------------

//**---------------------------------所有部门查询----------------------------------------------------/